import React from "react";

import ElementList from "./ElementList";
import ResultList from "./ResultList";
import ResultListItem from "./ResultListItem";
import CodeBlock from "../codeListing/CodeBlock";

import styles from "./AttributeDisplayFormList.module.scss";

export const AttributeDisplayFormListItem = ({ attributeDisplayForm, projectId }) => {
    return (
        <ResultListItem
            key={attributeDisplayForm.meta.identifier}
            title={attributeDisplayForm.meta.title}
            identifier={attributeDisplayForm.meta.identifier}
        >
            <ElementList
                displayForm={attributeDisplayForm}
                projectId={projectId}
                className={styles.Elements}
            />
        </ResultListItem>
    );
};

const AttributeDisplayFormHelp = () => {
    return (
        <>
            <p>
                <code>Attribute Display Forms</code> are metadata objects used to define{" "}
                <code>Attributes</code> of a certain format. For example "Employee ID" and "Employee Name" can
                be two <code>Attribute Display Forms</code> of an "Employee" <code>Attribute</code>.
            </p>
            <p>
                The format is almost always needed, this is why we mostly use{" "}
                <code>Attribute Display Forms</code> instead of general <code>Attributes</code>.
            </p>
            <p>
                Most common uses for <code>Attribute Display Forms</code> are:
            </p>
            <ul>
                <li>
                    <p>
                        Props defining Attributes in visualizations e.g. <code>viewBy</code> in a{" "}
                        <code>ColumnChart</code> component.
                    </p>
                    <CodeBlock>
                        {`import { ColumnChart, Model } from "@gooddata/react-components";

// ...

<ColumnChart
    projectId={projectId}
    measures={[Model.measure(measureIdentifier)]}
    viewBy={Model.attribute(attributeDisplayFormIdentifier)}
/>`}
                    </CodeBlock>
                </li>
                <li>
                    <p>Filtering visualizations using Attribute filters:</p>
                    <CodeBlock>
                        {`import { ColumnChart, Model } from "@gooddata/react-components";

// ...

<ColumnChart
    ...
    filters={[Model.attributeFilter(attributeDisplayFormIdentifier)
        .in("United States", "Canada")]}
/>`}
                    </CodeBlock>
                </li>
                <li>
                    <p>Sorting by Attribute Display Form value:</p>
                    <CodeBlock>
                        {`import { ColumnChart, Model } from "@gooddata/react-components";

// ...

<ColumnChart
    ...
    sortBy={[Model.attributeSortItem(attributeDisplayFormIdentifier, 'asc')]}
/>`}
                    </CodeBlock>
                </li>
            </ul>
        </>
    );
};

const AttributeDisplayFormList = ({ items, className, projectId }) => {
    return (
        <ResultList
            title="Attribute Display Forms"
            className={className}
            headerContent={<AttributeDisplayFormHelp />}
        >
            {items.map(attributeDisplayForm => (
                <AttributeDisplayFormListItem
                    key={attributeDisplayForm.meta.identifier}
                    attributeDisplayForm={attributeDisplayForm}
                    projectId={projectId}
                />
            ))}
        </ResultList>
    );
};

export default AttributeDisplayFormList;
