import React from "react";
import { ErrorComponent, BucketExecutor, Model } from "@gooddata/react-components";

import InlineLoading from "../InlineLoading";

const elementLimit = 3;

const ElementEnumeration = ({ items, totalCount }) => {
    const sourceArray =
        totalCount > elementLimit ? [...items, `and ${totalCount - elementLimit} more`] : items;

    return sourceArray.join(", ");
};

const ElementsError = () => <ErrorComponent message={"Error retrieving elements"} />;

const ElementList = ({ displayForm, projectId, className = null }) => {
    return (
        <div className={className}>
            <BucketExecutor
                projectId={projectId}
                dimensions={[[Model.attribute(displayForm.meta.identifier)]]}
                initialPaging={{ offset: [0], limit: [elementLimit] }}
                ErrorComponent={ElementsError}
                LoadingComponent={InlineLoading}
            >
                {({ result }) => {
                    const dimensionIndex = 0;
                    const attributeIndex = 0;
                    const attributeHeaders = result.headerItems[dimensionIndex][attributeIndex];
                    const attributeNames = attributeHeaders.map(({ attributeHeaderItem }) => {
                        return attributeHeaderItem.name || "(empty value)";
                    });
                    return <ElementEnumeration items={attributeNames} totalCount={result.paging.total[0]} />;
                }}
            </BucketExecutor>
        </div>
    );
};

export default ElementList;
