import React, { useState, useEffect, useCallback } from "react";
import { NavLink, Link } from "react-router-dom";
import throttle from "lodash/throttle";

import styles from "./Header.module.scss";
import logoUri from "./logo.svg";

const Logo = () => {
    return (
        <a href="https://sdk.gooddata.com/gooddata-ui/" className={styles.Logo} rel="noopener noreferrer">
            <img src={logoUri} alt="GoodData.UI Examples" className={styles.LogoImage} />
        </a>
    );
};

const Links = () => {
    return (
        <>
            <a
                href="https://sdk.gooddata.com/gooddata-ui/docs/about_gooddataui.html"
                className={styles.Link}
                rel="noopener noreferrer"
            >
                Docs
            </a>
            <a
                href="https://sdk.gooddata.com/gooddata-ui/docs/support_options.html"
                className={styles.Link}
                rel="noopener noreferrer"
            >
                Support
            </a>
            <a
                href="https://gooddata-examples.herokuapp.com/"
                className={styles.Link}
                rel="noopener noreferrer"
            >
                Live Examples
            </a>
            <NavLink
                to="/"
                isActive={(_, { pathname }) => pathname !== "/catalogue"}
                className={styles.Link}
                activeClassName={styles.LinkActive}
                aria-current="true"
            >
                My GoodData App
            </NavLink>
            <NavLink
                to="/catalogue"
                className={styles.Link}
                activeClassName={styles.LinkActive}
                aria-current="true"
            >
                Catalogue
            </NavLink>
        </>
    );
};

const Aside = () => {
    return (
        <div className={styles.Aside}>
            {/* <a
      href="https://github.com/gooddata/gooddata-react-components#run-live-examples-locally"
      target="_blank"
      rel="noopener noreferrer"
      className={styles.HeaderButton}
  >
      React components
  </a> */}
            <Link to="/logout" className={styles.HeaderLink}>
                Logout
            </Link>
        </div>
    );
};

const BurgerMenu = () => {
    const [isOpen, setIsOpen] = useState(false);
    return (
        <div className={styles.BurgerMenu}>
            <button
                className={styles.BurgerToggle}
                onClick={() => {
                    setIsOpen(!isOpen);
                }}
            >
                ☰
            </button>
            {isOpen && (
                <div className={styles.BurgerContent}>
                    <Links />
                </div>
            )}
        </div>
    );
};

const Header = () => {
    const [windowWidth, setWindowWidth] = useState(window ? window.innerWidth : null);

    const handleResize = useCallback(
        throttle(() => {
            if (window) {
                setWindowWidth(window.innerWidth);
            }
        }, 200),
        [],
    );

    useEffect(() => {
        window.addEventListener("resize", handleResize);
        return () => {
            window.removeEventListener("resize", handleResize);
        };
    }, [handleResize]);

    // You need to set this manually to the smallest window width that can still fit all menu items
    const isTooSmall = windowWidth < 852;
    return (
        <nav className={styles.Header}>
            {isTooSmall ? (
                <>
                    <BurgerMenu />
                    <Logo />
                </>
            ) : (
                <>
                    <Logo />
                    <Links />
                </>
            )}
            <Aside />
        </nav>
    );
};

export default Header;
