import React from "react";
import cx from "classnames";

import styles from "./GranularityPicker.module.scss";
import Button from "./Button";

const DATE = "GDC.time.date";
const WEEK_US = "GDC.time.week_us";
const MONTH = "GDC.time.month";
const QUARTER = "GDC.time.quarter";
const YEAR = "GDC.time.year";

const granularityNames = {
    [DATE]: "Day",
    [WEEK_US]: "Week (U.S.)",
    [MONTH]: "Month",
    [QUARTER]: "Quarter",
    [YEAR]: "Year",
}; // TODO obtain somehow from server?

const defaultGranularities = [DATE, WEEK_US, MONTH, QUARTER, YEAR];

const GranularityPicker = ({
    className = {},
    selectedGranularity,
    granularities = defaultGranularities,
    onChange,
}) => (
    <div className={cx(className, styles.GranularityPicker)}>
        {granularities.map(granularity => (
            <Button
                key={granularity}
                value={granularity}
                onClick={() => onChange(granularity)}
                active={selectedGranularity === granularity}
                className={styles.GranularityPickerButton}
            >
                {granularityNames[granularity]}
            </Button>
        ))}
    </div>
);

export default GranularityPicker;
