import React, { useEffect, useState, useCallback, memo } from "react";
import cx from "classnames";
import { Visualization } from "@gooddata/react-components";

import constants from "../../../constants";
import EditableVisualizationEditMode from "./EditableVisualizationEditMode";
import EditableVisualizationViewMode from "./EditableVisualizationViewMode";

import styles from "./EditableVisualizationWidget.module.scss";

const handlePostEvent = (event, onSave) => {
    const data = event.data && event.data.gdc ? event.data.gdc : null;
    if (data) {
        if (data.product === "analyticalDesigner" && data.event.name === "visualizationSaved") {
            onSave(data.event.data.visualizationObject);
        }
    }
};

const EMPTY_REPORT_IDENTIFIER = "reportId";
const defaultGetUri = (identifier = null) =>
    `${constants.backend}/analyze/embedded/#/${constants.projectId}/${identifier ||
        EMPTY_REPORT_IDENTIFIER}/edit`;

const EditableVisualization = ({
    getUri = defaultGetUri,
    className,
    showCode = true,
    identifier = null,
    Component = Visualization,
}) => {
    const [isEditing, setIsEditing] = useState(!identifier);
    const [visualizationIdentifier, setVisualizationIdentifier] = useState(identifier);

    const handlePostEventWithSave = useCallback(
        event =>
            handlePostEvent(event, visualizationObject => {
                const identifier = visualizationObject.meta.identifier;
                setIsEditing(false);
                setVisualizationIdentifier(identifier);
            }),
        [],
    );

    useEffect(() => {
        window.addEventListener("message", handlePostEventWithSave, false);
        return () => window.removeEventListener("message", handlePostEventWithSave, false);
    }, [handlePostEventWithSave]);

    return (
        <div className={cx(styles.EditableVisualization, className)}>
            {isEditing ? (
                <EditableVisualizationEditMode
                    iframeSrc={getUri(visualizationIdentifier)}
                    onCancelClick={() => {
                        setIsEditing(false);
                    }}
                    onClearClick={() => {
                        setVisualizationIdentifier(null);
                    }}
                />
            ) : (
                <EditableVisualizationViewMode
                    Component={Component}
                    allowShowCode={showCode}
                    onClearClick={() => {
                        setIsEditing(true);
                        setVisualizationIdentifier(null);
                    }}
                    onEditClick={() => {
                        setIsEditing(true);
                    }}
                    visualizationIdentifier={visualizationIdentifier}
                />
            )}
        </div>
    );
};

export default memo(EditableVisualization);
