import React, { createRef, useLayoutEffect, useRef } from "react";
import noop from "lodash/noop";

import Paging from "./Paging";

import styles from "./MeasureByAttributeChangeTable.module.scss";
import MeasureByAttributeChangeTableRow from "./MeasureByAttributeChangeTableRow";

const MeasureByAttributeChangeTable = ({ result, response, getPage, limit, onHeightChange = noop }) => {
    const data = result.data;
    const measureIndex = 1;
    const measureChangeIndex = 2;
    const measureGroupItems = response.dimensions[1].headers[0].measureGroupHeader.items;
    const measureFormat = measureGroupItems[measureIndex].measureHeaderItem.format;
    const measureChangeFormat = measureGroupItems[measureChangeIndex].measureHeaderItem.format;

    const tableRef = useRef(createRef());
    useLayoutEffect(() => {
        const newHeight = tableRef.current.current && tableRef.current.current.offsetHeight;
        onHeightChange(newHeight);
    });

    return (
        <>
            <div className={styles.ChangeTable} ref={tableRef.current}>
                {data.map((row, rowIndex) => (
                    <MeasureByAttributeChangeTableRow
                        data={data}
                        key={result.headerItems[0][0][rowIndex].attributeHeaderItem.uri}
                        measureChangeFormat={measureChangeFormat}
                        measureChangeIndex={measureChangeIndex}
                        measureFormat={measureFormat}
                        measureIndex={measureIndex}
                        result={result}
                        row={row}
                        rowIndex={rowIndex}
                    />
                ))}
            </div>
            <Paging currentPaging={result.paging} limit={limit} getPage={getPage} />
        </>
    );
};

export default MeasureByAttributeChangeTable;
