import React from "react";
import cx from "classnames";
import { numberFormat } from "@gooddata/numberjs";

import styles from "./MeasureByAttributeChangeTableRow.module.scss";

const MeasureByAttributeChangeTableRow = ({
    data,
    measureChangeFormat,
    measureChangeIndex,
    measureFormat,
    measureIndex,
    result,
    row,
    rowIndex,
}) => {
    const attributeValue = result.headerItems[0][0][rowIndex].attributeHeaderItem.name;
    const measureValue = parseFloat(row[measureIndex]);
    const measureChangeValue = parseFloat(row[measureChangeIndex]);
    const isChangeNegative = measureChangeValue < 0;
    const isLast = rowIndex === data.length - 1;
    const bar = (
        <div
            className={cx(
                styles.BarWrapper,
                isChangeNegative ? styles.Negative : styles.Positive,
                isLast && styles.Last,
            )}
        >
            <div
                className={styles.Bar}
                style={{
                    width: `${Math.min(100, Math.abs(Math.round(measureChangeValue * 100)))}%`,
                }}
            />
        </div>
    );
    return (
        <>
            <div className={cx(styles.AttributeValue, isLast && styles.Last)}>{attributeValue}</div>
            {isChangeNegative && bar}
            <div
                className={cx(
                    styles.Values,
                    isChangeNegative ? styles.Negative : styles.Positive,
                    isLast && styles.Last,
                )}
            >
                <span className={styles.Measure}>{numberFormat(measureValue, measureFormat)}</span>
                <span className={styles.MeasureChange}>
                    {numberFormat(measureChangeValue, measureChangeFormat)}
                </span>
            </div>
            {!isChangeNegative && bar}
        </>
    );
};

export default MeasureByAttributeChangeTableRow;
