import React from "react";
import cx from "classnames";
import { ErrorComponent } from "@gooddata/react-components";

import styles from "./MeasureByAttributeChangeWidget.module.scss";
import sharedStyles from "../../../shared.module.scss";

import CustomLoading from "../../CustomLoading";
import CatalogueConsumer from "../../CatalogueConsumer";
import MeasureByAttributeChangeWidgetBody from "./MeasureByAttributeChangeWidgetBody";
import MeasureByAttributeChangeTimePeriod from "./MeasureByAttributeChangeTimePeriod";

const MeasureByAttributeChangeWidget = ({
    headline = "No Headline",
    filters = [],
    attributeDisplayFormIdentifier = null,
    isAttributeDisplayFormFixed = false,
    measureIdentifier = null,
    isMeasureFixed = false,
    popAttributeIdentifier = "date.year",
    itemsPerPage = 10,
}) => {
    return (
        <div className={cx(styles.MeasureByAttributeChangeWidget, sharedStyles.Widget)}>
            <h3 className={cx(sharedStyles.Headline, styles.Headline)}>{headline}</h3>
            <MeasureByAttributeChangeTimePeriod filters={filters} />
            <CatalogueConsumer
                LoadingComponent={() => (
                    <div className={styles.Main}>
                        <CustomLoading />
                    </div>
                )}
                ErrorComponent={({ getPage, ...props }) => (
                    <div className={styles.Main}>
                        <ErrorComponent {...props} />
                    </div>
                )}
            >
                {catalogueData =>
                    catalogueData ? (
                        <MeasureByAttributeChangeWidgetBody
                            attributeDisplayFormIdentifier={attributeDisplayFormIdentifier}
                            catalogueData={catalogueData}
                            filters={filters}
                            isAttributeDisplayFormFixed={isAttributeDisplayFormFixed}
                            isMeasureFixed={isMeasureFixed}
                            itemsPerPage={itemsPerPage}
                            measureIdentifier={measureIdentifier}
                            popAttributeIdentifier={popAttributeIdentifier}
                        />
                    ) : null
                }
            </CatalogueConsumer>
        </div>
    );
};

export default MeasureByAttributeChangeWidget;
