import React from "react";
import cx from "classnames";

import Select from "../../controls/Select";
import {
    getCatalogItemsByType,
} from "../../../utils/catalogue";

import styles from "./VisualizationBuilderBucket.module.scss";

const VisualizationBuilderBucket = ({ bucket, bucketIndex, catalogue, buckets, setBuckets, errors }) => {
    const { prop, label, type, items, limit, factory, matchCatalogItem, isRequired } = bucket;
    const catalogueItems = getCatalogItemsByType(catalogue, type);

    const onBucketItemChange = bucketItemIndex => item => {
        const newBuckets = [...buckets];
        const newBucket = (newBuckets[bucketIndex] = {
            ...(buckets[bucketIndex] || {}),
            items: [...(buckets[bucketIndex].items || [])],
        });

        if (item.value === null) {
            newBucket.items = [
                ...(buckets[bucketIndex].items || []).slice(0, bucketItemIndex),
                ...(buckets[bucketIndex].items || []).slice(bucketItemIndex + 1),
            ];
        } else {
            newBucket.items[bucketItemIndex] = factory(item.value.meta.identifier);
        }
        setBuckets(newBuckets);
    };

    const bucketErrors = errors.filter(error => error.bucket === bucket);
    const bucketHasErrors = bucketErrors.length > 0;
    const canAddBucket = items.length < limit;

    return (
        <div key={prop} className={styles.Bucket}>
            <h4
                className={cx(
                    styles.BucketLabel,
                    isRequired && styles.Required,
                    bucketHasErrors && styles.Error,
                )}
                title={bucketErrors.map(error => error.message).join("")}
            >
                {label}
            </h4>
            {items.map((bucketItem, bucketItemIndex) => {
                const selectedItem = catalogueItems.find(catalogueItem =>
                    matchCatalogItem(bucketItem, catalogueItem),
                );
                return (
                    <Select
                        className={styles.BucketItemSelect}
                        key={bucketItemIndex}
                        items={[{ label: "remove", value: null }, ...catalogueItems]}
                        selectedItem={selectedItem}
                        onChange={onBucketItemChange(bucketItemIndex)}
                    />
                );
            })}
            {canAddBucket && (
                <Select
                    className={styles.BucketItemSelect}
                    key={items.length}
                    items={catalogueItems}
                    selectedItem={null}
                    onChange={onBucketItemChange(items.length)}
                />
            )}
        </div>
    );
};

export default VisualizationBuilderBucket;
