import React from "react";
import CustomLoading from "../../CustomLoading";
import ToggledCodeWithCopy from "../../codeListing/ToggledCodeWithCopy";
import Placeholder from "../../Placeholder";

import styles from "./VisualizationBuilderVisualization.module.scss";
import useComponentWithCode from "../../../hooks/useComponentWithCode";

const VisualizationBuilderVisualization = ({
    className = null,
    visType,
    buckets,
    projectId,
    visualizationProps = {},
    showCode = true,
    errors,
    ...restProps
}) => {
    const [Component, code] = useComponentWithCode(visType.component);

    const bucketsAreValid = visType ? errors.length === 0 : false;
    if (!visType || !projectId || !bucketsAreValid) {
        return (
            <div className={className} {...restProps}>
                <Placeholder type={visType ? visType.icon : undefined} className={styles.Placeholder} />
            </div>
        );
    }

    const bucketProps = buckets
        .filter(bucket => bucket.items.length > 0)
        .reduce((props, bucket) => {
            props[bucket.prop] = bucket.limit > 1 ? bucket.items : bucket.items[0];
            return props;
        }, {});

    return (
        <>
            <div className={className} {...restProps}>
                <Component
                    {...bucketProps}
                    LoadingComponent={CustomLoading}
                    projectId={projectId}
                    {...visualizationProps}
                />
            </div>
            {showCode && code && (
                <ToggledCodeWithCopy
                    code={code}
                    comment="This is the code of the visualization ready to be copy/pasted into your own application."
                />
            )}
        </>
    );
};

export default VisualizationBuilderVisualization;
