import {
    MEASURE,
    ATTRIBUTE,
    getMeasureQualifier,
    getAttributeQualifier,
    ATTRIBUTE_AND_DATE,
    DATE,
} from "../../../utils/bucketItems";
import {
    Model,
    ColumnChart,
    PieChart,
    PivotTable,
    AreaChart,
    LineChart,
    BarChart,
    Headline,
    ScatterPlot,
    BubbleChart,
    DonutChart,
    Treemap,
    Heatmap,
} from "@gooddata/react-components";

const measureFactory = measureIdentifier => {
    return Model.measure(measureIdentifier);
};

const attributeFactory = attributeIdentifier => {
    return Model.attribute(attributeIdentifier);
};

const qualifierCatalogItemMatcher = (qualifier, catalogueItem) => {
    if (!qualifier || !catalogueItem || !catalogueItem.value) {
        return false;
    }
    const qualifierKey = Object.keys(qualifier)[0];
    return catalogueItem.value.meta[qualifierKey] === qualifier[qualifierKey];
};

const measureCatalogItemMatcher = (bucketItem, catalogueItem) => {
    const qualifier = bucketItem && getMeasureQualifier(bucketItem);
    return qualifierCatalogItemMatcher(qualifier, catalogueItem);
};

const attributeCatalogItemMatcher = (bucketItem, catalogueItem) => {
    const qualifier = bucketItem && getAttributeQualifier(bucketItem);
    return qualifierCatalogItemMatcher(qualifier, catalogueItem);
};

export const measureBucket = {
    type: MEASURE,
    factory: measureFactory,
    matchCatalogItem: measureCatalogItemMatcher,
};

export const attributeAndDateBucket = {
    type: ATTRIBUTE_AND_DATE,
    factory: attributeFactory,
    matchCatalogItem: attributeCatalogItemMatcher,
};

export const attributeBucket = {
    type: ATTRIBUTE,
    factory: attributeFactory,
    matchCatalogItem: attributeCatalogItemMatcher,
};

export const dateBucket = {
    type: DATE,
    factory: attributeFactory,
    matchCatalogItem: attributeCatalogItemMatcher,
};

export const columnChartVisType = {
    label: "Column Chart",
    icon: "columnChart",
    component: ColumnChart,
    minimumBuckets: 1,
    buckets: [
        {
            ...measureBucket,
            label: "Measures",
            prop: "measures",
            limit: 20,
            isRequired: true,
            items: [],
        },
        {
            ...attributeAndDateBucket,
            label: "View by",
            prop: "viewBy",
            limit: 2,
            isRequired: false,
            items: [],
        },
        {
            ...attributeBucket,
            label: "Stack by",
            prop: "stackBy",
            limit: 1,
            isRequired: false,
            items: [],
        },
    ],
};

export const barChartVisType = {
    label: "Bar Chart",
    icon: "barChart",
    component: BarChart,
    minimumBuckets: 1,
    buckets: [
        {
            ...measureBucket,
            label: "Measures",
            prop: "measures",
            limit: 20,
            isRequired: true,
            items: [],
        },
        {
            ...attributeAndDateBucket,
            label: "View by",
            prop: "viewBy",
            limit: 2,
            isRequired: false,
            items: [],
        },
        {
            ...attributeAndDateBucket,
            label: "Stack by",
            prop: "stackBy",
            limit: 1,
            isRequired: false,
            items: [],
        },
    ],
};

export const lineChartVisType = {
    label: "Line Chart",
    icon: "lineChart",
    component: LineChart,
    minimumBuckets: 1,
    buckets: [
        {
            ...measureBucket,
            label: "Measures",
            prop: "measures",
            limit: 20,
            isRequired: true,
            items: [],
        },
        {
            ...dateBucket,
            label: "Trend by",
            prop: "trendBy",
            limit: 1,
            isRequired: false,
            items: [],
        },
        {
            ...attributeBucket,
            label: "Segment by",
            prop: "segmentBy",
            limit: 1,
            isRequired: false,
            items: [],
        },
    ],
};

export const areaChartVisType = {
    label: "Area Chart",
    icon: "areaChart",
    component: AreaChart,
    minimumBuckets: 1,
    buckets: [
        {
            ...measureBucket,
            label: "Measures",
            prop: "measures",
            limit: 20,
            isRequired: true,
            items: [],
        },
        {
            ...dateBucket,
            label: "View by",
            prop: "viewBy",
            limit: 1,
            isRequired: false,
            items: [],
        },
        {
            ...attributeBucket,
            label: "Stack by",
            prop: "stackby",
            limit: 1,
            isRequired: false,
            items: [],
        },
    ],
};

export const headlineVisType = {
    label: "Headline",
    icon: "headline",
    component: Headline,
    minimumBuckets: 1,
    buckets: [
        {
            ...measureBucket,
            label: "Primary measure",
            prop: "primaryMeasure",
            limit: 1,
            isRequired: true,
            items: [],
        },
        {
            ...measureBucket,
            label: "Secondary measure",
            prop: "secondaryMeasure",
            limit: 1,
            isRequired: false,
            items: [],
        },
    ],
};

export const scatterPlotVisType = {
    label: "Scatter Plot",
    icon: "scatterChart",
    component: ScatterPlot,
    minimumBuckets: 3,
    buckets: [
        {
            ...measureBucket,
            label: "X Measure",
            prop: "xAxisMeasure",
            limit: 1,
            isRequired: true,
            items: [],
        },
        {
            ...measureBucket,
            label: "Y Measure",
            prop: "yAxisMeasure",
            limit: 1,
            isRequired: true,
            items: [],
        },
        {
            ...attributeBucket,
            label: "Attribute",
            prop: "attribute",
            limit: 1,
            isRequired: true,
            items: [],
        },
    ],
};

export const bubbleChartVisType = {
    label: "Bubble Chart",
    icon: "bubbleChart",
    component: BubbleChart,
    minimumBuckets: 1,
    buckets: [
        {
            ...measureBucket,
            label: "X Measure",
            prop: "xAxisMeasure",
            limit: 1,
            isRequired: false,
            items: [],
        },
        {
            ...measureBucket,
            label: "Y Measure",
            prop: "yAxisMeasure",
            limit: 1,
            isRequired: false,
            items: [],
        },
        {
            ...measureBucket,
            label: "Size Measure",
            prop: "size",
            limit: 1,
            isRequired: false,
            items: [],
        },
        {
            ...attributeBucket,
            label: "ViewBy",
            prop: "viewBy",
            limit: 1,
            isRequired: false,
            items: [],
        },
    ],
};

export const pieChartVisType = {
    label: "Pie Chart",
    icon: "pieChart",
    component: PieChart,
    minimumBuckets: 1,
    buckets: [
        {
            ...measureBucket,
            label: "Measures",
            prop: "measures",
            limit: 20,
            isRequired: true,
            items: [],
        },
        {
            ...attributeAndDateBucket,
            label: "Attribute",
            prop: "viewBy",
            limit: 1,
            isRequired: false,
            items: [],
        },
    ],
};

export const donutChartVisType = {
    ...pieChartVisType,
    label: "Donut Chart",
    icon: "donutChart",
    component: DonutChart,
};

export const treemapVisType = {
    label: "Tree Map",
    icon: "treemap",
    component: Treemap,
    minimumBuckets: 1,
    buckets: [
        {
            ...measureBucket,
            label: "Measures",
            prop: "measures",
            limit: 20,
            isRequired: true,
            items: [],
        },
        {
            ...attributeAndDateBucket,
            label: "View by",
            prop: "viewBy",
            limit: 1,
            isRequired: false,
            items: [],
        },
        {
            ...attributeAndDateBucket,
            label: "Segment by",
            prop: "segmentBy",
            limit: 1,
            isRequired: false,
            items: [],
        },
    ],
};

export const heatmapVisType = {
    label: "Heatmap",
    icon: "heatmap",
    component: Heatmap,
    minimumBuckets: 2,
    buckets: [
        {
            ...measureBucket,
            label: "Measures",
            prop: "measure",
            limit: 1,
            isRequired: true,
            items: [],
        },
        {
            ...attributeAndDateBucket,
            label: "Rows",
            prop: "rows",
            limit: 1,
            isRequired: false,
            items: [],
        },
        {
            ...attributeAndDateBucket,
            label: "Columns",
            prop: "columns",
            limit: 1,
            isRequired: false,
            items: [],
        },
    ],
};

export const pivotTableVisType = {
    label: "Pivot Table",
    icon: "table",
    component: PivotTable,
    minimumBuckets: 1,
    buckets: [
        {
            ...measureBucket,
            label: "Measures",
            prop: "measures",
            limit: 20,
            isRequired: false,
            items: [],
        },
        {
            ...attributeAndDateBucket,
            label: "Rows",
            prop: "rows",
            limit: 20,
            isRequired: false,
            items: [],
        },
        {
            ...attributeAndDateBucket,
            label: "Columns",
            prop: "columns",
            limit: 4,
            isRequired: false,
            items: [],
        },
    ],
};

export const visTypes = [
    columnChartVisType,
    barChartVisType,
    lineChartVisType,
    areaChartVisType,
    headlineVisType,
    scatterPlotVisType,
    bubbleChartVisType,
    pieChartVisType,
    donutChartVisType,
    treemapVisType,
    heatmapVisType,
    pivotTableVisType,
];
