import React, { useState } from "react";
import { Model } from "@gooddata/react-components";
import { Container, Row, Col } from "react-grid-system";

import C from "../constants";
import ParametricDashboardBody from "../components/ParametricDashboard/ParametricDashboard";
import Page from "../components/Page";
import YearSelect from "../components/YearSelect";

import sharedStyles from "../shared.module.scss";

const ParametricDashboard = ({ match }) => {
    const [selectedYear, setSelectedYear] = useState(2017);

    const dateFilters = [
        Model.absoluteDateFilter(C.dateDataset, `${selectedYear}-01-01`, `${selectedYear}-12-31`),
    ];

    const { measures, primaryAttribute, dateAttribute } = match.params;

    return (
        <Page>
            <div className={sharedStyles.Header}>
                <Container fluid xs sm md lg>
                    <Row>
                        <Col className={sharedStyles.Column}>
                            <h2 className={sharedStyles.Title}>Parametric dashboard</h2>
                            <YearSelect value={selectedYear} onChange={setSelectedYear} />
                        </Col>
                    </Row>
                </Container>
            </div>
            <ParametricDashboardBody
                measures={measures ? measures.split(",") : []}
                primaryAttribute={primaryAttribute}
                dateAttribute={dateAttribute}
                dateFilters={dateFilters}
            />
        </Page>
    );
};

export default ParametricDashboard;
