import { VisualizationInput } from "@gooddata/typings";

export const MEASURE = "MEASURE";
export const DATE = "DATE";
export const ATTRIBUTE = "ATTRIBUTE";
export const ATTRIBUTE_AND_DATE = "ATTRIBUTE_AND_DATE";

export const getMeasureQualifier = bucketItem => bucketItem.measure.definition.measureDefinition.item;
export const getAttributeQualifier = bucketItem => bucketItem.visualizationAttribute.displayForm;

export const getQualifierMap = {
    [MEASURE]: getMeasureQualifier,
    [ATTRIBUTE]: getAttributeQualifier,
    [DATE]: getAttributeQualifier,
    [ATTRIBUTE_AND_DATE]: getAttributeQualifier,
};

export const getBucketItemType = bucketItem => {
    if (VisualizationInput.isMeasure(bucketItem)) {
        return MEASURE;
    }
    if (VisualizationInput.isAttribute(bucketItem)) {
        return ATTRIBUTE;
    }
    return undefined;
};

export const getBucketItemQualifiers = visProp => {
    if (!visProp || visProp.length === 0) {
        return [];
    }
    const bucketItems = Array.isArray(visProp) ? visProp : [visProp];
    const bucketItemType = getBucketItemType(bucketItems[0]);
    return bucketItems.map(bucketItem => {
        return getQualifierMap[bucketItemType](bucketItem);
    });
};
