import React from "react";

import ResultList from "./ResultList";
import ResultListItem from "./ResultListItem";
import { AttributeDisplayFormListItem } from "./AttributeDisplayFormList";

import ResultSubList from "./ResultSubList";

const AttributeListItem = ({ attribute, projectId }) => {
    return (
        <ResultListItem
            key={attribute.meta.identifier}
            title={attribute.meta.title}
            identifier={attribute.meta.identifier}
        >
            <ResultSubList heading="Display forms" >
                {attribute.content.displayForms.map(attributeDisplayForm => (
                    <AttributeDisplayFormListItem
                        key={attributeDisplayForm.meta.identifier}
                        projectId={projectId}
                        attributeDisplayForm={attributeDisplayForm}
                    />
                ))}
            </ResultSubList>
        </ResultListItem>
    );
};

const AttributeHelp = () => {
    return (
        <>
            <p>
                <code>Attributes</code> are metadata objects used to slice <code>Measures</code> by{" "}
                <code>Attribute</code> values. <code>Attributes</code> can contain multiple formats called{" "}
                <code>Attribute Display Forms</code>. For example an "Employee" <code>Attribute</code> can
                have two <code>Attribute Display Forms</code> "Employee ID" and "Employee Name".
            </p>
            <p>
                The format is almost always needed, this is why we mostly use{" "}
                <code>Attribute Display Forms</code> instead of general <code>Attributes</code>.
            </p>
        </>
    );
};

const AttributeList = ({ items, className, projectId }) => {
    return (
        <ResultList title="Attributes" className={className} headerContent={<AttributeHelp />}>
            {items.map(attribute => (
                <AttributeListItem
                    key={attribute.meta.identifier}
                    attribute={attribute}
                    projectId={projectId}
                />
            ))}
        </ResultList>
    );
};

export default AttributeList;
