import React from "react";
import { Kpi } from "@gooddata/react-components";

import ResultList from "./ResultList";
import ResultListItem from "./ResultListItem";
import CodeBlock from "../codeListing/CodeBlock";
import InlineLoading from "../InlineLoading";

const MeasureHelp = () => {
    return (
        <>
            <p>
                <code>Measures</code> are metadata objects used to define numeric values of data points.
            </p>
            <p>
                Most common uses for <code>Measures</code> are:
            </p>
            <ul>
                <li>
                    <p>
                        The value of a KPI prop <code>measure</code>
                    </p>
                    <CodeBlock>
                        {`import { Kpi } from "@gooddata/react-components";

// ...

<Kpi projectId={projectId} measure={measureIdentifier}/>`}
                    </CodeBlock>
                </li>
                <li>
                    <p>
                        Visualization prop <code>measure</code> or <code>measures</code>:
                    </p>
                    <CodeBlock>
                        {`import { ColumnChart, Model } from "@gooddata/react-components";

// ...

<ColumnChart
    projectId={projectId}
    measures={[Model.measure(measureIdentifier)]}
/>`}
                    </CodeBlock>
                </li>
                <li>
                    <p>Sorting by Measure value:</p>
                    <CodeBlock>
                        {`import { ColumnChart, Model } from "@gooddata/react-components";

// ...

<ColumnChart
    ...
    sortBy={[Model.measureSortItem(measureIdentifier, 'asc')]}
/>`}
                    </CodeBlock>
                </li>
            </ul>
        </>
    );
};

const MeasureListItem = ({ measure, projectId }) => (
    <ResultListItem
        key={measure.meta.identifier}
        title={measure.meta.title}
        identifier={measure.meta.identifier}
    >
        <Kpi projectId={projectId} measure={measure.meta.identifier} LoadingComponent={InlineLoading} />
    </ResultListItem>
);

const MeasureList = ({ items, className, projectId }) => {
    return (
        <ResultList title="Measures" className={className} headerContent={<MeasureHelp />}>
            {items.map(m => (
                <MeasureListItem key={m.meta.identifier} measure={m} projectId={projectId} />
            ))}
        </ResultList>
    );
};

export default MeasureList;
