import React from "react";
import cx from "classnames";

import styles from "./Placeholder.module.scss";

import barChartUri from "../media/visualization-types/bar.svg";
import barChartActiveUri from "../media/visualization-types/bar-active.svg";
import columnChartUri from "../media/visualization-types/column.svg";
import columnChartActiveUri from "../media/visualization-types/column-active.svg";
import lineChartUri from "../media/visualization-types/line.svg";
import lineChartActiveUri from "../media/visualization-types/line-active.svg";
import areaChartUri from "../media/visualization-types/area.svg";
import areaChartActiveUri from "../media/visualization-types/area-active.svg";
import pieChartUri from "../media/visualization-types/pie.svg";
import pieChartActiveUri from "../media/visualization-types/pie-active.svg";
import donutChartUri from "../media/visualization-types/donut.svg";
import donutChartActiveUri from "../media/visualization-types/donut-active.svg";
import headlineUri from "../media/visualization-types/headline.svg";
import headlineActiveUri from "../media/visualization-types/headline-active.svg";
import unknownUri from "../media/visualization-types/unknown.svg";
import unknownActiveUri from "../media/visualization-types/unknown-active.svg";
import scatterChartUri from "../media/visualization-types/scatter.svg";
import scatterChartActiveUri from "../media/visualization-types/scatter-active.svg";
import bubbleChartUri from "../media/visualization-types/bubble.svg";
import bubbleChartActiveUri from "../media/visualization-types/bubble-active.svg";
import treemapUri from "../media/visualization-types/treemap.svg";
import treemapActiveUri from "../media/visualization-types/treemap-active.svg";
import heatmapUri from "../media/visualization-types/heatmap.svg";
import heatmapActiveUri from "../media/visualization-types/heatmap-active.svg";
import tableUri from "../media/visualization-types/table.svg";
import tableActiveUri from "../media/visualization-types/table-active.svg";

export const imageUriMap = {
    barChart: barChartUri,
    barChartActive: barChartActiveUri,
    columnChart: columnChartUri,
    columnChartActive: columnChartActiveUri,
    lineChart: lineChartUri,
    lineChartActive: lineChartActiveUri,
    areaChart: areaChartUri,
    areaChartActive: areaChartActiveUri,
    pieChart: pieChartUri,
    pieChartActive: pieChartActiveUri,
    donutChart: donutChartUri,
    donutChartActive: donutChartActiveUri,
    headline: headlineUri,
    headlineActive: headlineActiveUri,
    scatterChart: scatterChartUri,
    scatterChartActive: scatterChartActiveUri,
    bubbleChart: bubbleChartUri,
    bubbleChartActive: bubbleChartActiveUri,
    treemap: treemapUri,
    treemapActive: treemapActiveUri,
    heatmap: heatmapUri,
    heatmapActive: heatmapActiveUri,
    unknown: unknownUri,
    unknownActive: unknownActiveUri,
    table: tableUri,
    tableActive: tableActiveUri,
};

export const randomIntRange = (min = 0, max = 1) => {
    return Math.floor(min + Math.random() * (max + 1 - min));
};

export const normalizeRange = value => {
    return Array.isArray(value) ? value : [value, value];
};

export const getParagraphLength = paragraph => {
    const wordSpaceLength = 1;
    return paragraph.reduce(
        (paragraphLength, wordLength) => paragraphLength + wordLength + wordSpaceLength,
        0,
    );
};

const characters = "abcdefghijklmnopqrstuvwxyz";
export const getRandomCharacter = () => {
    const randomIndex = randomIntRange(0, characters.length - 1);
    return characters[randomIndex];
};

export const TextPlaceholder = ({
    className = null,
    maxCharacterCount = [2000, 3000],
    wordCharacterCount = [2, 8],
    maxParagraphCharacterCount = [250, 500],
    minParagraphWordCount = 3,
    ...restProps
}) => {
    const wordSpaceLength = 1;
    const maxCharacterRange = normalizeRange(maxCharacterCount);
    const wordCharacterRange = normalizeRange(wordCharacterCount);
    const maxParagraphCharacterRange = normalizeRange(maxParagraphCharacterCount);
    const characterCountLimit = randomIntRange(...maxCharacterRange);

    const paragraphs = [];
    for (let characterCountLimitLeft = characterCountLimit; characterCountLimitLeft > 0; ) {
        const paragraph = [];
        let paragraphCharacterLimit = randomIntRange(
            ...maxParagraphCharacterRange.map(limit => Math.min(limit, characterCountLimitLeft)),
        );
        for (let paragraphCharacterLimitLeft = paragraphCharacterLimit; ; ) {
            const wordLength = randomIntRange(...wordCharacterRange);

            if (paragraphCharacterLimitLeft - wordLength - wordSpaceLength < 0) {
                break;
            }
            paragraphCharacterLimitLeft -= wordLength + wordSpaceLength;
            paragraph.push(wordLength);
        }
        const paragraphCharacterLength = getParagraphLength(paragraph);
        if (
            characterCountLimitLeft - paragraphCharacterLength < 0 ||
            paragraph.length < minParagraphWordCount
        ) {
            break;
        }
        characterCountLimitLeft -= paragraphCharacterLength;
        paragraphs.push(paragraph);
    }

    const content = paragraphs.map((paragraph, paragraphIndex) => {
        return (
            <p className={styles.Paragraph} key={`${paragraphIndex}${paragraph.join("")}`}>
                {paragraph.map((wordLength, wordIndex) => {
                    const fakeText = Array(wordLength)
                        .fill(null)
                        .map(() => getRandomCharacter())
                        .join("");
                    return (
                        <React.Fragment key={`${wordIndex}${fakeText}`}>
                            <span className={styles.Word}>{fakeText}</span>{" "}
                        </React.Fragment>
                    );
                })}
            </p>
        );
    });

    return (
        <div className={cx(styles.Text, className)} {...restProps}>
            {content}
        </div>
    );
};

export const imagePlaceholderTypeMap = Object.assign(
    {},
    ...Object.keys(imageUriMap).map(key => ({
        [key]: props => <ImagePlaceholder type={key} {...props} />,
    })),
);

export const ImagePlaceholder = ({
    type = "columnChart",
    className,
    style = {},
    imageSize = "auto",
    ...restProps
}) => {
    const myStyle = {
        backgroundImage: `url(${imageUriMap[type]})`,
        backgroundSize: imageSize,
        ...style,
    };
    return <div className={cx(styles.Block, className)} style={myStyle} {...restProps} />;
};

export const visTypes = [
    "barChart",
    "columnChart",
    "lineChart",
    "areaChart",
    "treemapChart",
    "pieChart",
    "donutChart",
    "headline",
    "scatterChart",
    "bubbleChart",
    "heatmap",
    "treemap",
    "table",
];

export const visToActiveVisMap = Object.assign(
    {},
    ...visTypes.map(visType => ({ [visType]: visType + "Active" })),
);

export const activeVisTypes = Object.values(visToActiveVisMap);

const placeholderTypeMap = {
    block: ({ className, ...restProps }) => <div className={cx(styles.Block, className)} {...restProps} />,
    ...imagePlaceholderTypeMap,
};

const Placeholder = ({ children = null, type = "block", ...restProps }) => {
    const PlaceholderComponent = placeholderTypeMap[type] || placeholderTypeMap["block"];
    return children ? <>{children}</> : <PlaceholderComponent {...restProps} />;
};

export default Placeholder;
