import React from "react";
import cx from "classnames";

import styles from "./VisTypePicker.module.scss";
import { visTypes as allVisTypes, imageUriMap, visToActiveVisMap } from "./Placeholder";
import Button from "./controls/Button";

const VisTypePicker = ({
    onChange,
    visTypes = allVisTypes,
    value,
    className = null,
    optionClassName = null,
    imageClassName = null,
    ...restProps
}) => {
    return (
        <div className={cx(className, styles.VisTypePicker)} {...restProps}>
            {visTypes.map(visType => {
                const isActive = value === visType;
                const type = isActive ? visToActiveVisMap[visType] : visType;
                return (
                    <Button
                        key={visType}
                        title={visType}
                        className={cx(styles.Option, isActive && styles.OptionActive, optionClassName)}
                        onClick={() => onChange(visType)}
                    >
                        <img
                            className={cx(styles.Image, imageClassName)}
                            src={imageUriMap[type]}
                            alt={visType}
                        />
                    </Button>
                );
            })}
        </div>
    );
};

export default VisTypePicker;
