import React from "react";

import Button from "../../controls/Button";

import useComponentWithCode from "../../../hooks/useComponentWithCode";
import CustomLoading from "../../CustomLoading";
import constants from "../../../constants";
import Placeholder from "../../Placeholder";
import ToggledCodeWithCopy from "../../codeListing/ToggledCodeWithCopy";

import styles from "./EditableVisualizationViewMode.module.scss";

const EditableVisualizationViewMode = ({
    Component,
    visualizationIdentifier,
    onClearClick,
    onEditClick,
    allowShowCode,
}) => {
    const [VisualizationWithCode, code] = useComponentWithCode(Component);
    return (
        <>
            <div className={styles.Actions}>
                <Button onClick={onClearClick}>Clear</Button>
                <Button onClick={onEditClick}>Edit</Button>
            </div>
            <div className={styles.Visualization}>
                {visualizationIdentifier ? (
                    <VisualizationWithCode
                        projectId={constants.projectId}
                        identifier={visualizationIdentifier}
                        LoadingComponent={CustomLoading}
                    />
                ) : (
                    <Placeholder type="columnChart" className={styles.Placeholder} />
                )}
            </div>
            {allowShowCode && code && (
                <div>
                    <ToggledCodeWithCopy
                        code={code}
                        comment="This is the code of the visualization ready to be copy/pasted into your own application."
                    />
                </div>
            )}
        </>
    );
};

export default EditableVisualizationViewMode;
