import React, { useCallback, useRef } from "react";
import { Model, BucketExecutor } from "@gooddata/react-components";

import CustomLoading from "../../CustomLoading";
import MeasureByAttributeChangeTable from "./MeasureByAttributeChangeTable";

const MeasureByAttributeChangeExecutor = ({
    catalogue,
    filters,
    popAttributeIdentifier,
    catalogueMeasure,
    catalogueAttributeDisplayForm,
    itemsPerPage,
}) => {
    const heightRef = useRef(0);
    const ResizedLoading = useCallback(() => <CustomLoading height={heightRef.current || undefined} />, [
        heightRef,
    ]);

    const measure = Model.measure(catalogueMeasure.meta.identifier);
    const popMeasure = Model.popMeasure(measure.measure.localIdentifier, popAttributeIdentifier);
    const rateMeasure = Model.arithmeticMeasure(
        [popMeasure.measure.localIdentifier, measure.measure.localIdentifier],
        "change",
    );
    const attribute = Model.attribute(catalogueAttributeDisplayForm.meta.identifier);
    const dimensions = [[attribute], [popMeasure, measure, rateMeasure]];
    const limit = [itemsPerPage, 3];
    return (
        <BucketExecutor
            projectId={catalogue.projectId}
            filters={filters}
            dimensions={dimensions}
            LoadingComponent={ResizedLoading}
            initialPaging={{ limit, offset: [0, 0] }}
        >
            {childrenProps => (
                <MeasureByAttributeChangeTable
                    {...childrenProps}
                    limit={limit}
                    onHeightChange={newHeight => {
                        heightRef.current = newHeight;
                    }}
                />
            )}
        </BucketExecutor>
    );
};

export default MeasureByAttributeChangeExecutor;
