import React, { memo } from "react";
import { LineChart } from "@gooddata/react-components";
import tinycolor from "tinycolor2";
import CustomLoading from "../../CustomLoading";
import useComponentWithCode from "../../../hooks/useComponentWithCode";
import ToggledCodeWithCopy from "../../codeListing/ToggledCodeWithCopy";

import styles from "./TrendWidgetGraph.module.scss";

const TrendWidgetGraph = ({ filters, trendBy, activeMeasures, projectId, colors }) => {
    const [LineChartWithCode, code] = useComponentWithCode(LineChart);

    const lineChartConfig = {
        colorPalette: colors.map((color, index) => ({
            fill: tinycolor(color).toRgb(),
            guid: String(index),
        })),
        legend: {
            enabled: false,
        },
    };

    return (
        <>
            <div className={styles.Chart}>
                <LineChartWithCode
                    filters={filters}
                    projectId={projectId}
                    measures={activeMeasures}
                    trendBy={trendBy}
                    config={lineChartConfig}
                    LoadingComponent={CustomLoading}
                />
            </div>
            <ToggledCodeWithCopy
                code={code}
                comment="This is the code of the visualization ready to be copy/pasted into your own application."
            />
        </>
    );
};

const areArraysSame = (xs, ys) =>
    xs === ys || (xs.length === ys.length && xs.every((x, index) => x === ys[index]));

export default memo(
    TrendWidgetGraph,
    (prevProps, nextProps) =>
        prevProps.filters === nextProps.filters &&
        (prevProps.trendBy === nextProps.trendBy ||
            prevProps.trendBy.visualizationAttribute.displayForm.identifier ===
                nextProps.trendBy.visualizationAttribute.displayForm.identifier) &&
        areArraysSame(prevProps.activeMeasures, nextProps.activeMeasures),
);
