import React from "react";
import cx from "classnames";
import { Kpi } from "@gooddata/react-components";
import tinycolor from "tinycolor2";

import styles from "./TrendWidgetMeasure.module.scss";
import CustomLoading from "../../CustomLoading";
import Select from "../../controls/Select";

const TrendWidgetMeasure = ({
    projectId,
    availableMeasures,
    selectedMeasure,
    onSelectedMeasureChange,
    isActive,
    isDisabled,
    onIsActiveChange,
    filters,
    color,
    readOnly,
}) => {
    const backgroundColor = isActive
        ? color
        : tinycolor(color)
              .greyscale()
              .lighten(30)
              .toHexString();

    const measures = [null];
    if (selectedMeasure) {
        measures.push(selectedMeasure);
    }
    measures.push(...availableMeasures);
    const items = measures.map(measure => ({
        label: measure ? measure.meta.title : "-remove-",
        value: measure,
    }));

    const selectedItem = items.find(item => (item ? item.value === selectedMeasure : false));

    const finalColor = isDisabled || !isActive ? "#94A1AD" : color;

    return (
        <div
            className={cx(styles.TrendWidgetMeasure, !isActive && styles.inactive)}
            style={{ borderBottomColor: backgroundColor }}
        >
            <Select
                disabled={isDisabled || readOnly}
                className={styles.Select}
                style={{ color: finalColor }}
                onChange={item => {
                    onSelectedMeasureChange(item.value ? item.value.meta.identifier : null);
                }}
                selectedItem={selectedItem}
                items={items}
                placeholder="Measure"
            />
            <div className={styles.Kpi} onClick={() => !readOnly && onIsActiveChange(!isActive)}>
                {selectedMeasure ? (
                    <Kpi
                        projectId={projectId}
                        measure={selectedMeasure.meta.identifier}
                        LoadingComponent={() => (
                            <CustomLoading imageHeight="1rem" inline color={finalColor} />
                        )}
                        filters={filters}
                    />
                ) : null}
            </div>
        </div>
    );
};

export default TrendWidgetMeasure;
