import React, { useState, useEffect } from "react";
import CatalogueContext from "./CatalogueContext";
import { defaultSourceState } from "../utils";
import {
    getAvailableDateDataSets,
    getDateDisplayFormsFor,
    normalizeDateDataSets,
} from "../utils/dateDataSets";
import constants from "../constants";
import { getCatalogueItems, normalizeCatalogueResponse } from "../utils/catalogue";
import useAuth from "../hooks/useAuth";

export const CatalogueProvider = ({ children }) => {
    const auth = useAuth();
    const [catalogue, setCatalogue] = useState({ ...defaultSourceState });

    useEffect(() => {
        if (!auth.data) {
            setCatalogue({
                ...defaultSourceState,
                isLoading: auth.isLoading,
                error: auth.isLoading ? null : "Unauthorized",
            });
            return;
        }
        const getCatalogue = async () => {
            setCatalogue({
                ...defaultSourceState,
                isLoading: true,
            });
            try {
                const dateDataSets = await getAvailableDateDataSets(constants.projectId);
                const defaultDateDataSet = dateDataSets[0];
                const defaultDateAttributeUri =
                    defaultDateDataSet.availableDateAttributes[0].attributeMeta.uri;

                const [catalogueResponse, dateDataAttributeDisplayForms] = await Promise.all([
                    getCatalogueItems(constants.projectId, [defaultDateAttributeUri]),
                    getDateDisplayFormsFor(dateDataSets, constants.projectId),
                ]);

                setCatalogue({
                    isLoading: false,
                    error: null,
                    data: {
                        ...normalizeCatalogueResponse(catalogueResponse),
                        projectId: constants.projectId,
                        dateDataSets: normalizeDateDataSets(dateDataSets, dateDataAttributeDisplayForms),
                        defaultDateDataSet: defaultDateDataSet.meta.identifier,
                    },
                });
            } catch (error) {
                setCatalogue({ ...defaultSourceState, isLoading: false, error });
            }
        };

        getCatalogue();
    }, [auth]);

    return <CatalogueContext.Provider value={catalogue}>{children}</CatalogueContext.Provider>;
};

export default CatalogueProvider;
