import React from "react";
import { BrowserRouter as Router, Route, Redirect } from "react-router-dom";
import "@gooddata/react-components/styles/css/main.css";

import Home from "./Home";
import Login from "./Login";
import Logout from "./Logout";
import Catalogue from "./Catalogue";
import MeasureByAttributeChange from "./MeasureByAttributeChange";
import StaticDashboard from "./StaticDashboard";
import DrillToModal from "./DrillToModal";
import VisualizationBuilder from "./VisualizationBuilder";
import Trend from "./Trend";
import EditableVisualization from "./EditableVisualization";
import ParametricDashboard from "./ParametricDashboard";
import useAuth from "../hooks/useAuth";

import styles from "./AppRouter.module.scss";

const AppRouter = () => {
    const auth = useAuth();

    const user = auth.data;
    const isLoading = auth.isLoading;
    const shouldRedirectToLogin = !isLoading && !user;

    return (
        <div className={styles.AppRouter}>
            <Router>
                <Route exact path="/" component={Home} />
                <Route exact path="/catalogue" component={Catalogue} />

                <Route exact path="/static-dashboard" component={StaticDashboard} />
                <Route exact path="/trend" component={Trend} />
                <Route exact path="/measure-by-attribute-change" component={MeasureByAttributeChange} />
                <Route exact path="/visualization-builder" component={VisualizationBuilder} />
                <Route exact path="/drill-to-modal" component={DrillToModal} />
                <Route exact path="/editable-visualization" component={EditableVisualization} />
                <Route
                    path="/parametric-dashboard/:primaryAttribute?/:dateAttribute?/:measures?"
                    component={ParametricDashboard}
                />

                <Route exact path="/login" component={Login} />
                <Route exact path="/logout" component={Logout} />
                {shouldRedirectToLogin && <Route component={() => <Redirect to="/login" />} />}
            </Router>
        </div>
    );
};

export default AppRouter;
