import React, { useState } from "react";
import { Container, Row, Col } from "react-grid-system";
import { Model } from "@gooddata/react-components";

import C from "../constants";
import Page from "../components/Page";
import YearSelect from "../components/YearSelect";
import TrendWidget from "../components/visualizations/TrendWidget/TrendWidget";

import sharedStyles from "../shared.module.scss";

const Trend = () => {
    const [selectedYear, setSelectedYear] = useState(2017);
    const dateFilters = [
        Model.absoluteDateFilter(C.dateDataset, `${selectedYear}-01-01`, `${selectedYear}-12-31`),
    ];

    return (
        <Page>
            <div className={sharedStyles.Header}>
                <Container fluid xs sm md lg>
                    <Row>
                        <Col className={sharedStyles.Column}>
                            <h2 className={sharedStyles.Title}>Measure By Attribute Change Widget</h2>
                            <YearSelect value={selectedYear} onChange={setSelectedYear} />
                        </Col>
                    </Row>
                </Container>
            </div>
            <Container fluid xs sm md lg>
                <Row>
                    <Col>
                        <TrendWidget
                            filters={dateFilters}
                            headline="Measure trends"
                            initialSelectedMeasuresIdentifiers={[
                                C.measures.grossProfit,
                                C.measures.totalSales,
                            ]}
                        />
                    </Col>
                </Row>
            </Container>
        </Page>
    );
};

export default Trend;
